--
-- Selected TOC Entries:
--
--
-- TOC Entry ID 2 (OID 1960475)
--
-- Name: connector Type: TABLE Owner: aliphe
--

CREATE TABLE connector (
	object_id integer NOT NULL,
	externalname character varying(20),
	userid integer NOT NULL,
	protocolid character varying(20) NOT NULL,
	driverid character varying(20) NOT NULL,
	port character varying(20),
	dbidsn character varying(250),
	ismaster character varying(20) DEFAULT 'MASTER',
	master_id integer,
	contextid character varying(50),
	proxy_id integer,
	Constraint connector_pkey Primary Key (object_id)
);

